# Folding@Home in docker

<div align="center">
  <img src="https://www.bleepstatic.com/images/news/software/f/folding-at-home/coronavirus/folding-at-home.jpg" />
</div>

# Descrizione

* [Sito ufficiale](https://foldingathome.org/)
* [Repo (Github)](https://github.com/linuxserver/docker-foldingathome)
* [Documentazione](https://docs.linuxserver.io/images/docker-foldingathome)

Folding@Home è un progetto di calcolo distribuito per aiutare la ricerca medica:

- Simulazione del comportamento delle proteine (e non solo) relative a malattie degenerative, infettive e altro
- Possibilità di selezionare, tramite l'interfaccia web, il tipo di ricerca da aiutare
- Possibilità di usare sia la CPU che la GPU
- Aiutare gli scienziati (di tutto il mondo) in modo indiretto

> **P.S è un progetto a cui tengo particolarmente, quindi anche se avete un computer vecchio che non usate, questo è il progetto perfetto per renderlo di nuovo utile a tutti.**

# Struttura file e cartelle

```
/home/
└── ~/
    └── docker/
        └── folding@home/
            ├── config/
            ├── .env
            └── docker-compose.yml
```

* `config/` - cartella dove risiedono i dati che servono a folding@home
* `.env` - file contenenti le variabili environment per il docker compose
* `docker-compose.yml` - file usato per creare il container

Tutti i file e le cartelle devono essere creati a mano.</br>

# docker-compose

`docker-compose.yml`
```yml
version: "3.4"
services:
  fah:
    container_name: linuxserver-fah
    image: ghcr.io/linuxserver/foldingathome
    restart: unless-stopped
    ports:
      - ${FAH_WEBUI_PORT:-7396}:7396
    env_file: .env
    volumes:
      - ${FAH_DATA:-/home/docker/folding@home/config}:/config
    healthcheck: # se modificate la porta dell'interfaccia web, ricordatevi di cambiarla anche qua sotto
      test: ["CMD", "curl", "-Ssf", http://localhost:7396"]
      interval: 1m30s
      timeout: 10s
      retries: 3
      start_period: 1m
```

`.env`
```bash
# Generale
FAH_WEBUI_PORT=7396
FAH_DATA=/home/docker/fah/data

# Folding@Home
TZ=Europe/Amsterdam
```

# Reverse proxy

Ancora non ho previsto l'uso di un reverse proxy. (Vedi [Todo](#Todo))

# Aggiornamenti

[Watchtower](https://github.com/DoTheEvo/selfhosted-apps-docker/tree/master/watchtower) aggiorna l'immagine automaticamente.

Aggiornamento manuale:

- `docker-compose pull`</br>
- `docker-compose up -d`</br>
- `docker image prune`

# Backup e ripristino

#### Backup

Copiare a mano, tramite crontab o altro la cartella `folding@home` (Vedi [Todo](#Todo))

#### Ripristino

* spegnere il container `docker-compose down`</br>
* cancellare l'intera cartella `folding@home`</br>
* dal backup copiare la cartella `folding@home`</br>
* far partire il container `docker-compose up -d`

# Todo

Implementare:
- reverse proxy: **[caddy](https://caddyserver.com/) o [traefik](https://doc.traefik.io/traefik/).**
- backup: **[borg](https://github.com/DoTheEvo/selfhosted-apps-docker/tree/master/borg_backup) per fare i backup giornalieri completi.**
