# Komga in docker

<div align="center">
  <img src="https://i.ibb.co/3hc9vKb/Screenshot-2021-05-17-Komga.png" />
</div>

# Descrizione

* [Sito ufficiale](https://komga.org/)
* [Repo (Github)](https://github.com/gotson/komga)
* [Demo](https://demo.komga.org/) Login: ```demo@komga.org``` Password: ```komga-demo```
* [Documentazione](https://komga.org/guides/)

Komga è un server per la gestione di manga/comics:

- Interfaccia web moderna e compatibile con tablet e smartphone
- Possibilità di organizzare i vostri file in collezioni
- Possibilità di modificare e importare i metadati locali (e integrati)
- Multiutente, con possiblità di gestire l'accesso alle librerie (anche singolarmente)
- Supporto ai maggiori tipi di formati (CBZ, CBR, PDF e EPUB)
- Possibilità di interazione esterna tramite REST API

# Struttura file e cartelle

```
/home/
└── ~/
    └── docker/
        └── komga/
            ├── config/
            ├── data/
            ├── .env
            └── docker-compose.yml
```

* `config/` - cartella dove risiedono i dati che servono a komga
* `data/` - cartella dove vanno messi i manga/comics
* `.env` - file contenenti le variabili environment per il docker compose
* `docker-compose.yml` - file usato per creare il container

Tutti i file e le cartelle devono essere creati a mano.</br>

# docker-compose

`docker-compose.yml`
```yml
version: "3"
services:
  komga:
    container_name: komga
    image: gotson/komga
    restart: unless-stopped
    ports:
      - ${KOMGA_WEBUI_PORT:-8080}:8080
    env_file: .env
    volumes:
      - ${KOMGA_CONFIG:-/home/docker/komga/config}:/config
      - ${KOMGA_DATA:-/home/docker/komga/data:/data
```

`.env`
```bash
# Generale
KOMGA_WEBUI_PORT=8080
KOMGA_CONFIG=/config
KOMGA_DATA=/data

# Komga
ND_LOGLEVEL=info
```

# Reverse proxy

Ancora non ho previsto l'uso di un reverse proxy. (Vedi [Todo](#Todo))

# Aggiornamenti

[Watchtower](https://github.com/DoTheEvo/selfhosted-apps-docker/tree/master/watchtower) aggiorna l'immagine automaticamente.

Aggiornamento manuale:

- `docker-compose pull`</br>
- `docker-compose up -d`</br>
- `docker image prune`

# Backup e ripristino

#### Backup

Copiare a mano, tramite crontab o altro la cartella `komga` (Vedi [Todo](#Todo))

#### Ripristino

* spegnere il container `docker-compose down`</br>
* cancellare l'intera cartella `komga`</br>
* dal backup copiare la cartella `komga`</br>
* far partire il container `docker-compose up -d`

# Todo

Implementare:
- reverse proxy: **[caddy](https://caddyserver.com/) o [traefik](https://doc.traefik.io/traefik/).**
- backup: **[borg](https://github.com/DoTheEvo/selfhosted-apps-docker/tree/master/borg_backup) per fare i backup giornalieri completi.**
